==> contentsquare-1.0.1.tar.gz: example/simple_app/lib/src/screens/api_tests/api_tests_screen.dart <==
import 'package:auto_route/auto_route.dart';
import 'package:contentsquare/contentsquare.dart';
import 'package:contentsquare_example/routes/app_router.dart';
import 'package:contentsquare_example/src/screens/api_tests/widgets/webview/webview_screen.dart';
import 'package:flutter/material.dart';

import '../../utils/navigate_and_monitor.dart';
import 'widgets/dynamic_variable/dynamic_variable_screen.dart';
import 'widgets/transaction/transaction_screen.dart';

class APITestsScreen extends StatelessWidget {
  const APITestsScreen({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.only(top: 30.0),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Padding(
            padding: EdgeInsets.symmetric(horizontal: 16),
            child: Text(
              'Select an API functionnality',
              style: Theme.of(context).textTheme.headline6,
            ),
          ),
          SizedBox(height: 20),
          ListTile(
            title: Text('Privacy'),
            onTap: () async {
              await Contentsquare().send('PrivacyRoute');
              await context.router.push(PrivacyRoute());
            },
          ),
          SizedBox(height: 10),
          ListTile(
            title: Text('Transaction'),
            onTap: () => navigateAndMonitor(context, TransactionScreen()),
          ),
          SizedBox(height: 10),
          ListTile(
            title: Text('Dynamic variable'),
            onTap: () => navigateAndMonitor(context, DynamicVariableScreen()),
          ),
          SizedBox(height: 10),
          ListTile(
            title: Text('WebView'),
            onTap: () => navigateAndMonitor(context, WebViewScreen()),
          ),
          SizedBox(height: 10),
        ],
      ),
    );
  }
}

==> contentsquare-2.3.0.tar.gz: example/simple_app/lib/src/screens/api_tests/api_tests_screen.dart <==
import 'package:auto_route/auto_route.dart';
import 'package:contentsquare/contentsquare.dart';
import 'package:contentsquare_example/routes/app_router.dart';
import 'package:contentsquare_example/src/screens/api_tests/widgets/webview/webview_screen.dart';
import 'package:flutter/material.dart';

import '../../utils/navigate_and_monitor.dart';
import 'widgets/dynamic_variable/dynamic_variable_screen.dart';
import 'widgets/transaction/transaction_screen.dart';

class APITestsScreen extends StatelessWidget {
  const APITestsScreen({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.only(top: 30.0),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Padding(
            padding: EdgeInsets.symmetric(horizontal: 16),
            child: Text(
              'Select an API functionnality',
              style: Theme.of(context).textTheme.titleLarge,
            ),
          ),
          SizedBox(height: 20),
          ListTile(
            title: Text('Privacy'),
            onTap: () async {
              await Contentsquare().send('PrivacyRoute');
              await context.router.push(PrivacyRoute());
            },
          ),
          SizedBox(height: 10),
          ListTile(
            title: Text('Transaction'),
            onTap: () => navigateAndMonitor(context, TransactionScreen()),
          ),
          SizedBox(height: 10),
          ListTile(
            title: Text('Dynamic variable'),
            onTap: () => navigateAndMonitor(context, DynamicVariableScreen()),
          ),
          SizedBox(height: 10),
          ListTile(
            title: Text('WebView'),
            onTap: () => navigateAndMonitor(context, WebViewScreen()),
          ),
          SizedBox(height: 10),
        ],
      ),
    );
  }
}
